@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# (c) 2009-2022 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Original PyFileServer (c) 2005 Ho Chun Wei.
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/mit-license.php
@@ -20,7 +20,7 @@ import shutil
 import stat
 import sys
 
-from wsgidav import compat, util
+from wsgidav import util
 from wsgidav.dav_error import HTTP_FORBIDDEN, DAVError
 from wsgidav.dav_provider import DAVCollection, DAVNonCollection, DAVProvider
 
@@ -41,12 +41,12 @@ class FileResource(DAVNonCollection):
     """
 
     def __init__(self, path, environ, file_path):
-        super(FileResource, self).__init__(path, environ)
+        super().__init__(path, environ)
         self._file_path = file_path
         self.file_stat = os.stat(self._file_path)
         # Setting the name from the file path should fix the case on Windows
         self.name = os.path.basename(self._file_path)
-        self.name = compat.to_native(self.name)
+        self.name = util.to_str(self.name)
 
     # Getter methods for standard live properties
     def get_content_length(self):
@@ -62,7 +62,7 @@ class FileResource(DAVNonCollection):
         return self.name
 
     def get_etag(self):
-        return util.get_etag(self._file_path)
+        return util.get_file_etag(self._file_path)
 
     def get_last_modified(self):
         return self.file_stat[stat.ST_MTIME]
@@ -84,7 +84,7 @@ class FileResource(DAVNonCollection):
         # content-length will be wrong.
         return open(self._file_path, "rb", BUFFER_SIZE)
 
-    def begin_write(self, content_type=None):
+    def begin_write(self, *, content_type=None):
         """Open content as a stream for writing.
 
         See DAVResource.begin_write()
@@ -104,10 +104,10 @@ class FileResource(DAVNonCollection):
         if self.provider.readonly:
             raise DAVError(HTTP_FORBIDDEN)
         os.unlink(self._file_path)
-        self.remove_all_properties(True)
-        self.remove_all_locks(True)
+        self.remove_all_properties(recursive=True)
+        self.remove_all_locks(recursive=True)
 
-    def copy_move_single(self, dest_path, is_move):
+    def copy_move_single(self, dest_path, *, is_move):
         """See DAVResource.copy_move_single()"""
         if self.provider.readonly:
             raise DAVError(HTTP_FORBIDDEN)
@@ -156,7 +156,7 @@ class FileResource(DAVNonCollection):
                 environ=self.environ,
             )
 
-    def set_last_modified(self, dest_path, time_stamp, dry_run):
+    def set_last_modified(self, dest_path, time_stamp, *, dry_run):
         """Set last modified time for destPath to timeStamp on epoch-format"""
         # Translate time from RFC 1123 to seconds since epoch format
         secs = util.parse_time_string(time_stamp)
@@ -175,13 +175,12 @@ class FolderResource(DAVCollection):
     """
 
     def __init__(self, path, environ, file_path):
-        super(FolderResource, self).__init__(path, environ)
+        super().__init__(path, environ)
         self._file_path = file_path
-        #        self._dict = None
         self.file_stat = os.stat(self._file_path)
         # Setting the name from the file path should fix the case on Windows
         self.name = os.path.basename(self._file_path)
-        self.name = compat.to_native(self.name)  # .encode("utf8")
+        self.name = util.to_str(self.name)  # .encode("utf8")
 
     # Getter methods for standard live properties
     def get_creation_date(self):
@@ -213,20 +212,20 @@ class FolderResource(DAVCollection):
 
         nameList = []
         # self._file_path is unicode, so os.listdir returns unicode as well
-        assert compat.is_unicode(self._file_path)
+        assert util.is_str(self._file_path)
         # if "temp" in self._file_path:
         #     raise RuntimeError("Oops")
         for name in os.listdir(self._file_path):
-            if not compat.is_unicode(name):
+            if not util.is_str(name):
                 name = name.decode(sys.getfilesystemencoding())
-            assert compat.is_unicode(name)
+            assert util.is_str(name)
             # Skip non files (links and mount points)
             fp = os.path.join(self._file_path, name)
             if not os.path.isdir(fp) and not os.path.isfile(fp):
                 _logger.debug("Skipping non-file {!r}".format(fp))
                 continue
             # name = name.encode("utf8")
-            name = compat.to_native(name)
+            name = util.to_str(name)
             nameList.append(name)
         return nameList
 
@@ -235,9 +234,9 @@ class FolderResource(DAVCollection):
 
         See DAVCollection.get_member()
         """
-        assert compat.is_native(name), "{!r}".format(name)
-        fp = os.path.join(self._file_path, compat.to_unicode(name))
-        #        name = name.encode("utf8")
+        assert util.is_str(name), "{!r}".format(name)
+        fp = os.path.join(self._file_path, util.to_str(name))
+        # name = name.encode("utf8")
         path = util.join_uri(self.path, name)
         if os.path.isdir(fp):
             res = FolderResource(path, self.environ, fp)
@@ -284,10 +283,10 @@ class FolderResource(DAVCollection):
         if self.provider.readonly:
             raise DAVError(HTTP_FORBIDDEN)
         shutil.rmtree(self._file_path, ignore_errors=False)
-        self.remove_all_properties(True)
-        self.remove_all_locks(True)
+        self.remove_all_properties(recursive=True)
+        self.remove_all_locks(recursive=True)
 
-    def copy_move_single(self, dest_path, is_move):
+    def copy_move_single(self, dest_path, *, is_move):
         """See DAVResource.copy_move_single()"""
         if self.provider.readonly:
             raise DAVError(HTTP_FORBIDDEN)
@@ -343,7 +342,7 @@ class FolderResource(DAVCollection):
                 environ=self.environ,
             )
 
-    def set_last_modified(self, dest_path, time_stamp, dry_run):
+    def set_last_modified(self, dest_path, time_stamp, *, dry_run):
         """Set last modified time for destPath to timeStamp on epoch-format"""
         # Translate time from RFC 1123 to seconds since epoch format
         secs = util.parse_time_string(time_stamp)
@@ -356,17 +355,21 @@ class FolderResource(DAVCollection):
 # FilesystemProvider
 # ========================================================================
 class FilesystemProvider(DAVProvider):
-    def __init__(self, root_folder_path, readonly=False):
-        # Expand leading '~' as user home dir; expand %VAR%, $Var, ..
-        root_folder_path = os.path.expandvars(os.path.expanduser(root_folder_path))
-        root_folder_path = os.path.abspath(root_folder_path)
-        if not root_folder_path or not os.path.exists(root_folder_path):
-            raise ValueError("Invalid root path: {}".format(root_folder_path))
+    def __init__(self, root_folder, *, readonly=False, shadow=None):
+        # and resolve relative to config file
+        # root_folder = os.path.expandvars(os.xpath.expanduser(root_folder))
+        root_folder = os.path.abspath(root_folder)
+        if not root_folder or not os.path.exists(root_folder):
+            raise ValueError("Invalid root path: {}".format(root_folder))
 
-        super(FilesystemProvider, self).__init__()
+        super().__init__()
 
-        self.root_folder_path = root_folder_path
+        self.root_folder_path = root_folder
         self.readonly = readonly
+        if shadow:
+            self.shadow = {k.lower(): v for k, v in shadow.items()}
+        else:
+            self.shadow = {}
 
     def __repr__(self):
         rw = "Read-Write"
@@ -376,6 +379,28 @@ class FilesystemProvider(DAVProvider):
             self.__class__.__name__, self.root_folder_path, rw
         )
 
+    def _resolve_shadow_path(self, path, environ, file_path):
+        """File not found: See if there is a shadow configured."""
+        shadow = self.shadow.get(path.lower())
+        # _logger.info(f"Shadow {path} -> {shadow} {self.shadow}")
+        if not shadow:
+            return False, file_path
+
+        err = None
+        method = environ["REQUEST_METHOD"].upper()
+        if method not in ("GET", "HEAD", "OPTIONS"):
+            err = f"Shadow {path} -> {shadow}: ignored for method {method!r}."
+        elif os.path.exists(file_path):
+            err = f"Shadow {path} -> {shadow}: ignored for existing resource {file_path!r}."
+        elif not os.path.exists(shadow):
+            err = f"Shadow {path} -> {shadow}: does not exist."
+
+        if err:
+            _logger.warning(err)
+            return False, file_path
+        _logger.info(f"Shadow {path} -> {shadow}")
+        return True, shadow
+
     def _loc_to_file_path(self, path, environ=None):
         """Convert resource path to a unicode absolute file path.
         Optional environ argument may be useful e.g. in relation to per-user
@@ -383,12 +408,13 @@ class FilesystemProvider(DAVProvider):
         """
         root_path = self.root_folder_path
         assert root_path is not None
-        assert compat.is_native(root_path)
-        assert compat.is_native(path)
+        assert util.is_str(root_path)
+        assert util.is_str(path)
 
         path_parts = path.strip("/").split("/")
         file_path = os.path.abspath(os.path.join(root_path, *path_parts))
-        if not file_path.startswith(root_path):
+        is_shadow, file_path = self._resolve_shadow_path(path, environ, file_path)
+        if not file_path.startswith(root_path) and not is_shadow:
             raise RuntimeError(
                 "Security exception: tried to access file outside root: {}".format(
                     file_path
