@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# (c) 2009-2022 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
 """
 Tools that make it easier to implement custom WsgiDAV providers.
@@ -7,7 +7,7 @@ Tools that make it easier to implement custom WsgiDAV providers.
 import os
 import stat
 
-from wsgidav import compat, util
+from wsgidav import util
 from wsgidav.dav_provider import DAVCollection, DAVNonCollection
 
 __docformat__ = "reStructuredText en"
@@ -27,8 +27,8 @@ class VirtualCollection(DAVCollection):
     """
 
     def __init__(self, path, environ, display_info, member_name_list):
-        super(VirtualCollection, self).__init__(path, environ)
-        if compat.is_basestring(display_info):
+        super().__init__(path, environ)
+        if util.is_basestring(display_info):
             display_info = {"type": display_info}
         assert type(display_info) is dict
         assert type(member_name_list) is list
@@ -59,7 +59,7 @@ class _VirtualNonCollection(DAVNonCollection):
     """Abstract base class for all non-collection resources."""
 
     def __init__(self, path, environ):
-        super(_VirtualNonCollection, self).__init__(path, environ)
+        super().__init__(path, environ)
 
     def get_content_length(self):
         return None
@@ -101,7 +101,7 @@ class VirtualTextResource(_VirtualNonCollection):
     """A virtual file, containing a string."""
 
     def __init__(self, path, environ, content, display_name=None, display_type=None):
-        super(VirtualTextResource, self).__init__(path, environ)
+        super().__init__(path, environ)
         self.content = content
         self.display_name = display_name
         self.display_type = display_type
@@ -125,10 +125,10 @@ class VirtualTextResource(_VirtualNonCollection):
 
     #    def get_ref_url(self):
     #        refPath = "/by_key/%s/%s" % (self._data["key"], self.name)
-    #        return compat.quote(self.provider.share_path + refPath)
+    #        return quote(self.provider.share_path + refPath)
 
     def get_content(self):
-        return compat.StringIO(self.content)
+        return util.StringIO(self.content)
 
 
 # ============================================================================
@@ -142,7 +142,7 @@ class FileResource(_VirtualNonCollection):
     def __init__(self, path, environ, file_path):
         if not os.path.exists(file_path):
             _logger.error("FileResource({!r}) does not exist.".format(file_path))
-        super(FileResource, self).__init__(path, environ)
+        super().__init__(path, environ)
         self.file_path = file_path
 
     def get_content_length(self):
@@ -171,7 +171,7 @@ class FileResource(_VirtualNonCollection):
 
     #    def get_ref_url(self):
     #        refPath = "/by_key/%s/%s" % (self._data["key"], os.path.basename(self.file_path))
-    #        return compat.quote(self.provider.share_path + refPath)
+    #        return quote(self.provider.share_path + refPath)
 
     def get_content(self):
         # mime = self.get_content_type()
@@ -184,7 +184,7 @@ class FileResource(_VirtualNonCollection):
 # ============================================================================
 # Resolvers
 # ============================================================================
-class DAVResolver(object):
+class DAVResolver:
     """Return a DAVResource object for a path (None, if not found)."""
 
     def __init__(self, parent_resolver, name):
