@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# (c) 2009-2022 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
 """
 Implementation of a WebDAV provider that provides a very basic, read-only
@@ -24,12 +24,13 @@ Valid options are (sample shows defaults)::
             }
 
 """
+from io import StringIO
 from pprint import pformat
 
 import pymongo
 from bson.objectid import ObjectId
 
-from wsgidav import compat, util
+from wsgidav import util
 from wsgidav.dav_provider import DAVCollection, DAVNonCollection, DAVProvider
 from wsgidav.util import join_uri
 
@@ -88,7 +89,7 @@ class CollCollection(DAVCollection):
     def get_member_names(self):
         res = []
         for doc in self.coll.find():
-            res.append(compat.to_native(doc["_id"]))
+            res.append(util.to_str(doc["_id"]))
         return res
 
     def get_member(self, name):
@@ -105,7 +106,7 @@ class DocResource(DAVNonCollection):
 
     def get_content(self):
         html = "<pre>" + pformat(self.doc) + "</pre>"
-        return compat.StringIO(html.encode("utf8"))
+        return StringIO(html.encode("utf8"))
 
     def get_content_length(self):
         return len(self.get_content().read())
@@ -120,8 +121,8 @@ class DocResource(DAVNonCollection):
         elif doc.get("title"):
             return doc["title"].encode("utf8")
         elif doc.get("_id"):
-            return compat.to_native(doc["_id"])
-        return compat.to_native(doc["key"])
+            return util.to_str(doc["_id"])
+        return util.to_str(doc["key"])
 
     def get_display_info(self):
         return {"type": "Mongo document"}
@@ -134,7 +135,7 @@ class MongoResourceProvider(DAVProvider):
     """DAV provider that serves a MongoDB structure."""
 
     def __init__(self, options):
-        super(MongoResourceProvider, self).__init__()
+        super().__init__()
         self.options = options
         self.conn = pymongo.Connection(options.get("host"), options.get("port"))
         if options.get("user"):
